Changes
=======

0.5.0
-----

- Pin requirements-parser to version 0.4.0

0.4.0
-----

- Add ``--errors-only`` flag for only displaying problems
- Add ``--user`` flag for showing all packages from a given PyPI user
- Fix dependency ``reqfile-parser`` is now ``requirements-parser``
- Fix incorrect link counts and count URLs instead

0.3.0
-----

- Improve error message when package not hosted on PyPI
- Improve README

0.2.0
-----

- Raise exception when package not hosted on PyPI

0.1.0
-----

Initial release.
